==> polymer-networking-0.14.4+1.21.10-sources.jar: eu/pb4/polymer/networking/api/PolymerNetworking.java <==
package eu.pb4.polymer.networking.api;

import eu.pb4.polymer.networking.impl.ClientPackets;
import eu.pb4.polymer.networking.impl.ExtClientConnection;
import eu.pb4.polymer.networking.impl.ServerPacketRegistry;
import eu.pb4.polymer.networking.impl.ServerPackets;
import io.netty.buffer.ByteBuf;
import it.unimi.dsi.fastutil.ints.IntList;
import net.minecraft.class_2520;
import net.minecraft.class_2535;
import net.minecraft.class_2960;
import net.minecraft.class_4614;
import net.minecraft.class_8710;
import net.minecraft.class_9139;
import org.jetbrains.annotations.Nullable;

public final class PolymerNetworking {
    private PolymerNetworking() {}

    @Nullable
    public static <T extends class_2520> T getMetadata(class_2535 handler, class_2960 identifier, class_4614<T> type) {
        var x = ExtClientConnection.of(handler).polymerNet$getMetadataMap().get(identifier);
        if (x != null && x.method_23258() == type) {
            //noinspection unchecked
            return (T) x;
        }
        return null;
    }

    public static <T extends class_8710> void registerS2CSimple(class_2960 identifier, class_9139<ContextByteBuf, T> codec) {
        registerS2CSimple(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerS2CSimple(class_2960 identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerS2CSimple(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerS2CSimple(class_2960 identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerS2C(identifier, versions, ContextByteBuf.simple(codec));
    }

    public static <T extends class_8710> void registerS2CVersioned(class_2960 identifier, class_9139<ContextByteBuf, T> codec) {
        registerS2CVersioned(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerS2CVersioned(class_2960 identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerS2CVersioned(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerS2CVersioned(class_2960 identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerS2C(identifier, versions, ContextByteBuf.versioned(identifier, codec));
    }

    public static <T extends class_8710> void registerC2SSimple(class_2960 identifier, class_9139<ContextByteBuf, T> codec) {
        registerC2SSimple(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerC2SSimple(class_2960 identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerC2SSimple(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerC2SSimple(class_2960 identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerC2S(identifier, versions, ContextByteBuf.simple(codec));
    }

    public static <T extends class_8710> void registerC2SVersioned(class_2960 identifier, class_9139<ContextByteBuf, T> codec) {
        registerC2SVersioned(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerC2SVersioned(class_2960 identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerC2SVersioned(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerC2SVersioned(class_2960 identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerC2S(identifier, versions, ContextByteBuf.versioned(identifier, codec));
    }

    public static <T extends class_8710> void registerCommonSimple(class_2960 identifier, class_9139<ContextByteBuf, T> codec) {
        registerCommonSimple(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerCommonSimple(class_2960 identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerCommonSimple(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerCommonSimple(class_2960 identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerCommon(identifier, versions, ContextByteBuf.simple(codec));
    }

    public static <T extends class_8710> void registerCommonVersioned(class_2960 identifier, class_9139<ContextByteBuf, T> codec) {
        registerCommonVersioned(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerCommonVersioned(class_2960 identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerCommonVersioned(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerCommonVersioned(class_2960 identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerCommon(identifier, versions, ContextByteBuf.versioned(identifier, codec));
    }

    public static <T extends class_8710> void registerS2CSimple(class_8710.class_9154<T> identifier, class_9139<ContextByteBuf, T> codec) {
        registerS2CSimple(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerS2CSimple(class_8710.class_9154<T> identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerS2CSimple(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerS2CSimple(class_8710.class_9154<T> identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerS2CSimple(identifier.comp_2242(), versions, codec);
    }

    public static <T extends class_8710> void registerS2CVersioned(class_8710.class_9154<T> identifier, class_9139<ContextByteBuf, T> codec) {
        registerS2CVersioned(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerS2CVersioned(class_8710.class_9154<T> identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerS2CVersioned(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerS2CVersioned(class_8710.class_9154<T> identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerS2CVersioned(identifier.comp_2242(), versions, codec);
    }

    public static <T extends class_8710> void registerC2SSimple(class_8710.class_9154<T> identifier, class_9139<ContextByteBuf, T> codec) {
        registerC2SSimple(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerC2SSimple(class_8710.class_9154<T> identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerC2SSimple(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerC2SSimple(class_8710.class_9154<T> identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerC2SSimple(identifier.comp_2242(), versions, codec);
    }

    public static <T extends class_8710> void registerC2SVersioned(class_8710.class_9154<T> identifier, class_9139<ContextByteBuf, T> codec) {
        registerC2SVersioned(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerC2SVersioned(class_8710.class_9154<T> identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerC2SVersioned(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerC2SVersioned(class_8710.class_9154<T> identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerC2SVersioned(identifier.comp_2242(), versions, codec);
    }

    public static <T extends class_8710> void registerCommonSimple(class_8710.class_9154<T> identifier, class_9139<ContextByteBuf, T> codec) {
        registerCommonSimple(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerCommonSimple(class_8710.class_9154<T> identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerCommonSimple(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerCommonSimple(class_8710.class_9154<T> identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerCommonSimple(identifier.comp_2242(), versions, codec);
    }

    public static <T extends class_8710> void registerCommonVersioned(class_8710.class_9154<T> identifier, class_9139<ContextByteBuf, T> codec) {
        registerCommonVersioned(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerCommonVersioned(class_8710.class_9154<T> identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerCommonVersioned(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerCommonVersioned(class_8710.class_9154<T> identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerCommonVersioned(identifier.comp_2242(), versions, codec);
    }



    private static <T extends class_8710> void registerCommon(class_2960 identifier, IntList versions, class_9139<ByteBuf, T> codec) {
        registerS2C(identifier, versions, codec);
        registerC2S(identifier, versions, codec);
    }

    public static int getSupportedVersion(class_2535 connection, class_2960 identifier) {
        return connection != null ? ExtClientConnection.of(connection).polymerNet$getSupportedVersion(identifier) : -1;
    }

    private static <T extends class_8710> void registerS2C(class_2960 identifier, IntList versions, class_9139<ByteBuf, T> codec) {
        ServerPackets.register(identifier, codec, versions.toIntArray());
    }
    private static <T extends class_8710> void registerC2S(class_2960 identifier, IntList versions, class_9139<ByteBuf, T> codec) {
        ClientPackets.register(identifier, codec, versions.toIntArray());
    }
    public static <T extends class_8710> class_8710.class_9154<T> id(String id) {
        return new class_8710.class_9154<>(class_2960.method_60654(id));
    }

    public static <T extends class_8710> class_8710.class_9154<T> id(String namespace, String path) {
        return new class_8710.class_9154<>(class_2960.method_60655(namespace, path));
    }
}

==> polymer-networking-0.15.0+1.21.11-sources.jar: eu/pb4/polymer/networking/api/PolymerNetworking.java <==
package eu.pb4.polymer.networking.api;

import eu.pb4.polymer.networking.impl.ClientPackets;
import eu.pb4.polymer.networking.impl.ExtConnection;
import eu.pb4.polymer.networking.impl.ServerPackets;
import io.netty.buffer.ByteBuf;
import it.unimi.dsi.fastutil.ints.IntList;
import net.minecraft.class_2520;
import net.minecraft.class_2535;
import net.minecraft.class_2960;
import net.minecraft.class_4614;
import net.minecraft.class_8710;
import net.minecraft.class_9139;
import org.jetbrains.annotations.Nullable;

public final class PolymerNetworking {
    private PolymerNetworking() {}

    @Nullable
    public static <T extends class_2520> T getMetadata(class_2535 handler, class_2960 identifier, class_4614<T> type) {
        var x = ExtConnection.of(handler).polymerNet$getMetadataMap().get(identifier);
        if (x != null && x.method_23258() == type) {
            //noinspection unchecked
            return (T) x;
        }
        return null;
    }

    public static <T extends class_8710> void registerS2CSimple(class_2960 identifier, class_9139<ContextByteBuf, T> codec) {
        registerS2CSimple(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerS2CSimple(class_2960 identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerS2CSimple(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerS2CSimple(class_2960 identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerS2C(identifier, versions, ContextByteBuf.simple(codec));
    }

    public static <T extends class_8710> void registerS2CVersioned(class_2960 identifier, class_9139<ContextByteBuf, T> codec) {
        registerS2CVersioned(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerS2CVersioned(class_2960 identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerS2CVersioned(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerS2CVersioned(class_2960 identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerS2C(identifier, versions, ContextByteBuf.versioned(identifier, codec));
    }

    public static <T extends class_8710> void registerC2SSimple(class_2960 identifier, class_9139<ContextByteBuf, T> codec) {
        registerC2SSimple(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerC2SSimple(class_2960 identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerC2SSimple(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerC2SSimple(class_2960 identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerC2S(identifier, versions, ContextByteBuf.simple(codec));
    }

    public static <T extends class_8710> void registerC2SVersioned(class_2960 identifier, class_9139<ContextByteBuf, T> codec) {
        registerC2SVersioned(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerC2SVersioned(class_2960 identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerC2SVersioned(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerC2SVersioned(class_2960 identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerC2S(identifier, versions, ContextByteBuf.versioned(identifier, codec));
    }

    public static <T extends class_8710> void registerCommonSimple(class_2960 identifier, class_9139<ContextByteBuf, T> codec) {
        registerCommonSimple(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerCommonSimple(class_2960 identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerCommonSimple(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerCommonSimple(class_2960 identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerCommon(identifier, versions, ContextByteBuf.simple(codec));
    }

    public static <T extends class_8710> void registerCommonVersioned(class_2960 identifier, class_9139<ContextByteBuf, T> codec) {
        registerCommonVersioned(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerCommonVersioned(class_2960 identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerCommonVersioned(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerCommonVersioned(class_2960 identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerCommon(identifier, versions, ContextByteBuf.versioned(identifier, codec));
    }

    public static <T extends class_8710> void registerS2CSimple(class_8710.class_9154<T> identifier, class_9139<ContextByteBuf, T> codec) {
        registerS2CSimple(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerS2CSimple(class_8710.class_9154<T> identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerS2CSimple(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerS2CSimple(class_8710.class_9154<T> identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerS2CSimple(identifier.comp_2242(), versions, codec);
    }

    public static <T extends class_8710> void registerS2CVersioned(class_8710.class_9154<T> identifier, class_9139<ContextByteBuf, T> codec) {
        registerS2CVersioned(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerS2CVersioned(class_8710.class_9154<T> identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerS2CVersioned(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerS2CVersioned(class_8710.class_9154<T> identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerS2CVersioned(identifier.comp_2242(), versions, codec);
    }

    public static <T extends class_8710> void registerC2SSimple(class_8710.class_9154<T> identifier, class_9139<ContextByteBuf, T> codec) {
        registerC2SSimple(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerC2SSimple(class_8710.class_9154<T> identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerC2SSimple(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerC2SSimple(class_8710.class_9154<T> identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerC2SSimple(identifier.comp_2242(), versions, codec);
    }

    public static <T extends class_8710> void registerC2SVersioned(class_8710.class_9154<T> identifier, class_9139<ContextByteBuf, T> codec) {
        registerC2SVersioned(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerC2SVersioned(class_8710.class_9154<T> identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerC2SVersioned(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerC2SVersioned(class_8710.class_9154<T> identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerC2SVersioned(identifier.comp_2242(), versions, codec);
    }

    public static <T extends class_8710> void registerCommonSimple(class_8710.class_9154<T> identifier, class_9139<ContextByteBuf, T> codec) {
        registerCommonSimple(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerCommonSimple(class_8710.class_9154<T> identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerCommonSimple(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerCommonSimple(class_8710.class_9154<T> identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerCommonSimple(identifier.comp_2242(), versions, codec);
    }

    public static <T extends class_8710> void registerCommonVersioned(class_8710.class_9154<T> identifier, class_9139<ContextByteBuf, T> codec) {
        registerCommonVersioned(identifier, 0, codec);
    }

    public static <T extends class_8710> void registerCommonVersioned(class_8710.class_9154<T> identifier, int version, class_9139<ContextByteBuf, T> codec) {
        registerCommonVersioned(identifier, IntList.of(version), codec);
    }

    public static <T extends class_8710> void registerCommonVersioned(class_8710.class_9154<T> identifier, IntList versions, class_9139<ContextByteBuf, T> codec) {
        registerCommonVersioned(identifier.comp_2242(), versions, codec);
    }



    private static <T extends class_8710> void registerCommon(class_2960 identifier, IntList versions, class_9139<ByteBuf, T> codec) {
        registerS2C(identifier, versions, codec);
        registerC2S(identifier, versions, codec);
    }

    public static int getSupportedVersion(class_2535 connection, class_2960 identifier) {
        return connection != null ? ExtConnection.of(connection).polymerNet$getSupportedVersion(identifier) : -1;
    }

    private static <T extends class_8710> void registerS2C(class_2960 identifier, IntList versions, class_9139<ByteBuf, T> codec) {
        ServerPackets.register(identifier, codec, versions.toIntArray());
    }
    private static <T extends class_8710> void registerC2S(class_2960 identifier, IntList versions, class_9139<ByteBuf, T> codec) {
        ClientPackets.register(identifier, codec, versions.toIntArray());
    }
    public static <T extends class_8710> class_8710.class_9154<T> id(String id) {
        return new class_8710.class_9154<>(class_2960.method_60654(id));
    }

    public static <T extends class_8710> class_8710.class_9154<T> id(String namespace, String path) {
        return new class_8710.class_9154<>(class_2960.method_60655(namespace, path));
    }
}
